#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 HTTP
version:              4000.3.16
visibility:           public
id:                   HTTP-4000.3.16-E5lYYPLbbkB5ENeU5ceNHw
key:                  HTTP-4000.3.16-E5lYYPLbbkB5ENeU5ceNHw
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Warrick Gray <warrick.gray@hotmail.com>
homepage:             https://github.com/haskell/HTTP
synopsis:             A library for client-side HTTP
description:
    The HTTP package supports client-side web programming in Haskell. It lets you set up
    HTTP connections, transmitting requests and processing the responses coming back, all
    from within the comforts of Haskell. It'\''s dependent on the network package to operate,
    but other than that, the implementation is all written in Haskell.

    A basic API for issuing single HTTP requests + receiving responses is provided. On top
    of that, a session-level abstraction is also on offer  (the @BrowserAction@ monad);
    it taking care of handling the management of persistent connections, proxies,
    state (cookies) and authentication credentials required to handle multi-step
    interactions with a web server.

    The representation of the bytes flowing across is extensible via the use of a type class,
    letting you pick the representation of requests and responses that best fits your use.
    Some pre-packaged, common instances are provided for you (@ByteString@, @String@).

    Here'\''s an example use:

    >
    >    do
    >      rsp <- Network.HTTP.simpleHTTP (getRequest "http://www.haskell.org/")
    >              -- fetch document and return it (as a '\''String'\''.)
    >      fmap (take 100) (getResponseBody rsp)
    >
    >    do
    >      (_, rsp)
    >         <- Network.Browser.browse $ do
    >               setAllowRedirects True -- handle HTTP redirects
    >               request $ getRequest "http://www.haskell.org/"
    >      return (take 100 (rspBody rsp))

    __Note:__ This package does not support HTTPS connections.
    If you need HTTPS, take a look at the following packages:

    * <http://hackage.haskell.org/package/http-streams http-streams>

    * <http://hackage.haskell.org/package/http-client http-client> (in combination with
    <http://hackage.haskell.org/package/http-client-tls http-client-tls>)

    * <http://hackage.haskell.org/package/req req>

    * <http://hackage.haskell.org/package/wreq wreq>

category:             Network
abi:                  619c225a04a515da27b6dea42cced6ef
exposed:              True
exposed-modules:
    Network.Browser Network.BufferType Network.HTTP Network.HTTP.Auth
    Network.HTTP.Base Network.HTTP.Cookie Network.HTTP.HandleStream
    Network.HTTP.Headers Network.HTTP.Proxy Network.HTTP.Stream
    Network.Stream Network.StreamDebugger Network.StreamSocket
    Network.TCP

hidden-modules:
    Network.HTTP.Base64 Network.HTTP.MD5Aux Network.HTTP.Utils
    Paths_HTTP

import-dirs:          /usr/lib/ghc-8.10.4/site-local/HTTP-4000.3.16
library-dirs:         /usr/lib/ghc-8.10.4/site-local/HTTP-4000.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/HTTP-4000.3.16
hs-libraries:         HSHTTP-4000.3.16-E5lYYPLbbkB5ENeU5ceNHw
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 mtl-2.2.2
    network-3.1.2.1-DRWh3PXxLpgEA96GNEGjqt
    network-uri-2.6.4.1-J4xKR5bjyl4EwNDOZsZp7W parsec-3.1.14.0
    time-1.9.3

haddock-interfaces:   /usr/share/doc/haskell-http/html/HTTP.haddock
haddock-html:         /usr/share/doc/haskell-http/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

